Documentation
¶
Overview ¶
Package ifc holds miscellaneous interfaces used by kustomize.
Index ¶
Constants ¶
const SecretTypeOpaque = "Opaque"
See core.v1.SecretTypeOpaque
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KustHasher ¶ added in v0.8.6
KustHasher returns a hash of the argument or an error.
type KvLoader ¶
type KvLoader interface {
Validator() Validator
Load(args types.KvPairSources) (all []types.Pair, err error)
}
KvLoader reads and validates KV pairs.
type Loader ¶
type Loader interface {
// Root returns the root location for this Loader.
Root() string
// New returns Loader located at newRoot.
New(newRoot string) (Loader, error)
// Load returns the bytes read from the location or an error.
Load(location string) ([]byte, error)
// Cleanup cleans the loader
Cleanup() error
}
Loader interface exposes methods to read bytes.
type Validator ¶
type Validator interface {
MakeAnnotationValidator() func(map[string]string) error
MakeAnnotationNameValidator() func([]string) error
MakeLabelValidator() func(map[string]string) error
MakeLabelNameValidator() func([]string) error
ValidateNamespace(string) []string
ErrIfInvalidKey(string) error
IsEnvVarName(k string) error
}
Validator provides functions to validate annotations and labels
Click to show internal directories.
Click to hide internal directories.