Documentation
¶
Overview ¶
Package ifc holds miscellaneous interfaces used by kustomize.
Index ¶
Constants ¶
const SecretTypeOpaque = "Opaque"
See core.v1.SecretTypeOpaque
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Kunstructured ¶
type Kunstructured interface {
Copy() Kunstructured
GetAnnotations() map[string]string
GetBool(path string) (bool, error)
GetFieldValue(string) (interface{}, error)
GetFloat64(path string) (float64, error)
GetGvk() resid.Gvk
GetInt64(path string) (int64, error)
GetKind() string
GetLabels() map[string]string
GetMap(path string) (map[string]interface{}, error)
GetName() string
GetSlice(path string) ([]interface{}, error)
GetString(string) (string, error)
GetStringMap(path string) (map[string]string, error)
GetStringSlice(string) ([]string, error)
Map() map[string]interface{}
MarshalJSON() ([]byte, error)
MatchesAnnotationSelector(selector string) (bool, error)
MatchesLabelSelector(selector string) (bool, error)
Patch(Kunstructured) error
SetAnnotations(map[string]string)
SetGvk(resid.Gvk)
SetLabels(map[string]string)
SetMap(map[string]interface{})
SetName(string)
SetNamespace(string)
UnmarshalJSON([]byte) error
}
Kunstructured allows manipulation of k8s objects that do not have Golang structs.
type KunstructuredFactory ¶
type KunstructuredFactory interface {
SliceFromBytes([]byte) ([]Kunstructured, error)
FromMap(m map[string]interface{}) Kunstructured
Hasher() KunstructuredHasher
MakeConfigMap(kvLdr KvLoader, args *types.ConfigMapArgs) (Kunstructured, error)
MakeSecret(kvLdr KvLoader, args *types.SecretArgs) (Kunstructured, error)
}
KunstructuredFactory makes instances of Kunstructured.
type KunstructuredHasher ¶
type KunstructuredHasher interface {
Hash(Kunstructured) (string, error)
}
KunstructuredHasher returns a hash of the argument or an error.
type KvLoader ¶
type KvLoader interface {
Validator() Validator
Load(args types.KvPairSources) (all []types.Pair, err error)
}
KvLoader reads and validates KV pairs.
type Loader ¶
type Loader interface {
// Root returns the root location for this Loader.
Root() string
// New returns Loader located at newRoot.
New(newRoot string) (Loader, error)
// Load returns the bytes read from the location or an error.
Load(location string) ([]byte, error)
// Cleanup cleans the loader
Cleanup() error
}
Loader interface exposes methods to read bytes.
type Validator ¶
type Validator interface {
MakeAnnotationValidator() func(map[string]string) error
MakeAnnotationNameValidator() func([]string) error
MakeLabelValidator() func(map[string]string) error
MakeLabelNameValidator() func([]string) error
ValidateNamespace(string) []string
ErrIfInvalidKey(string) error
IsEnvVarName(k string) error
}
Validator provides functions to validate annotations and labels
Click to show internal directories.
Click to hide internal directories.